package com.ruoyi.sip.controller;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.sip.domain.OrderDelivery;
import com.ruoyi.sip.service.IOrderDeliveryService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 发货记录Controller
 * 
 * @author mula
 * @date 2025-04-11
 */
@Controller
@RequestMapping("/manage/delivery")
public class OrderDeliveryController extends BaseController
{
    private String prefix = "manage/delivery";

    @Autowired
    private IOrderDeliveryService orderDeliveryService;

    @RequiresPermissions("manage:delivery:view")
    @GetMapping()
    public String delivery()
    {
        return prefix + "/delivery";
    }

    /**
     * 查询发货记录列表
     */
    @RequiresPermissions("manage:delivery:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(OrderDelivery orderDelivery)
    {
        startPage();
        List<OrderDelivery> list = orderDeliveryService.selectOrderDeliveryList(orderDelivery);
        return getDataTable(list);
    }

    /**
     * 导出发货记录列表
     */
    @RequiresPermissions("manage:delivery:export")
    @Log(title = "发货记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(OrderDelivery orderDelivery)
    {
        List<OrderDelivery> list = orderDeliveryService.selectOrderDeliveryList(orderDelivery);
        ExcelUtil<OrderDelivery> util = new ExcelUtil<OrderDelivery>(OrderDelivery.class);
        return util.exportExcel(list, "发货记录数据");
    }

    /**
     * 新增发货记录
     */
    @RequiresPermissions("manage:delivery:add")
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存发货记录
     */
    @RequiresPermissions("manage:delivery:add")
    @Log(title = "发货记录", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(OrderDelivery orderDelivery)
    {
        return toAjax(orderDeliveryService.insertOrderDelivery(orderDelivery));
    }

    /**
     * 修改发货记录
     */
    @RequiresPermissions("manage:delivery:edit")
    @GetMapping("/edit/{id}")
    public String edit(@PathVariable("id") Long id, ModelMap mmap)
    {
        OrderDelivery orderDelivery = orderDeliveryService.selectOrderDeliveryById(id);
        mmap.put("orderDelivery", orderDelivery);
        return prefix + "/edit";
    }

    /**
     * 修改保存发货记录
     */
    @RequiresPermissions("manage:delivery:edit")
    @Log(title = "发货记录", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(OrderDelivery orderDelivery)
    {
        return toAjax(orderDeliveryService.updateOrderDelivery(orderDelivery));
    }

    /**
     * 删除发货记录
     */
    @RequiresPermissions("manage:delivery:remove")
    @Log(title = "发货记录", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(orderDeliveryService.deleteOrderDeliveryByIds(ids));
    }
}
