package com.ruoyi.sip.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.sip.mapper.OrderDeliveryMapper;
import com.ruoyi.sip.domain.OrderDelivery;
import com.ruoyi.sip.service.IOrderDeliveryService;
import com.ruoyi.common.core.text.Convert;

/**
 * 发货记录Service业务层处理
 * 
 * @author mula
 * @date 2025-04-11
 */
@Service
public class OrderDeliveryServiceImpl implements IOrderDeliveryService 
{
    @Autowired
    private OrderDeliveryMapper orderDeliveryMapper;

    /**
     * 查询发货记录
     * 
     * @param id 发货记录主键
     * @return 发货记录
     */
    @Override
    public OrderDelivery selectOrderDeliveryById(Long id)
    {
        return orderDeliveryMapper.selectOrderDeliveryById(id);
    }

    /**
     * 查询发货记录列表
     * 
     * @param orderDelivery 发货记录
     * @return 发货记录
     */
    @Override
    public List<OrderDelivery> selectOrderDeliveryList(OrderDelivery orderDelivery)
    {
        return orderDeliveryMapper.selectOrderDeliveryList(orderDelivery);
    }

    /**
     * 新增发货记录
     * 
     * @param orderDelivery 发货记录
     * @return 结果
     */
    @Override
    public int insertOrderDelivery(OrderDelivery orderDelivery)
    {
        return orderDeliveryMapper.insertOrderDelivery(orderDelivery);
    }

    /**
     * 修改发货记录
     * 
     * @param orderDelivery 发货记录
     * @return 结果
     */
    @Override
    public int updateOrderDelivery(OrderDelivery orderDelivery)
    {
        return orderDeliveryMapper.updateOrderDelivery(orderDelivery);
    }

    /**
     * 批量删除发货记录
     * 
     * @param ids 需要删除的发货记录主键
     * @return 结果
     */
    @Override
    public int deleteOrderDeliveryByIds(String ids)
    {
        return orderDeliveryMapper.deleteOrderDeliveryByIds(Convert.toStrArray(ids));
    }

    /**
     * 删除发货记录信息
     * 
     * @param id 发货记录主键
     * @return 结果
     */
    @Override
    public int deleteOrderDeliveryById(Long id)
    {
        return orderDeliveryMapper.deleteOrderDeliveryById(id);
    }
}
